@@ -5,7 +5,9 @@ use warnings;
 
 package Nginx::ParseLog;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
+
+use Regexp::IPv6 qw($IPv6_re);
 
 
 =head1 NAME
@@ -42,33 +44,33 @@ sub parse {
     chomp $log_string;
 
     # print "$log_string\n";
-    my $ip = qr/(?:\d+\.){3}\d+/;
+    my $IPv4_re = qr/(?:\d+\.){3}\d+/;
   
-    #                      ip         remote_user   time         request    status   bytes_send  referer    user_agent
-    if ( $log_string =~ m/^($ip)\s-\s (.*?)\s         \[(.*?)\]\s  "(.*?)"\s  (\d+)\s  (\d+)\s     "(.*?)"\s  "(.*?)"$/x) {
-	my $deparsed = { };
-	my $c = 0;
+    #                      ip                       remote_user   time         request    status   bytes_send  referer    user_agent
+    if ( $log_string =~ m/^($IPv4_re|$IPv6_re)\s-\s (.*?)\s         \[(.*?)\]\s  "(.*?)"\s  (\d+)\s  (\d+)\s     "(.*?)"\s  "(.*?)"$/x) {
+        my $deparsed = { };
+        my $c = 0;
         
-	my @field_list = qw/
-            ip 		
-	    remote_user
+        my @field_list = qw/
+            ip
+            remote_user
             time     
             request 
             status  
             bytes_send
             referer  
             user_agent 
-	/;
+        /;
 
-	{
-	    no strict 'refs'; # some Perl magic
+        {
+            no strict 'refs'; # some Perl magic
 
-	    for (@field_list) {
-	        $deparsed->{ $_  } = ${ ++$c };
+            for (@field_list) {
+                $deparsed->{ $_  } = ${ ++$c };
             }
-	}
-	
-	return $deparsed;
+        }
+
+        return $deparsed;
     } else {
         return;
     }
